@@ -8,7 +8,7 @@ use English;
 use Error::Pure qw(err);
 use List::Util qw(none);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub new {
 	my ($class, @params) = @_;
@@ -69,10 +69,24 @@ sub new {
 	return $self;
 }
 
-sub insert {
-	my $self = shift;
+sub data {
+	my ($self, $variables_hr) = @_;
 
-	my $data_hr = $self->data;
+	err 'Package __PACKAGE__ is abstract class. data() method must be '.
+		'defined in inherited class.';
+}
+
+sub insert {
+	my ($self, $variables_hr) = @_;
+
+	# Check required variables.
+	foreach my $required_variable ($self->required_variables) {
+		if (! exists $variables_hr->{$required_variable}) {
+			err "Variable '$required_variable' is required.";
+		}
+	}
+
+	my $data_hr = $self->data($variables_hr);
 	my %sources = map { ($self->{'_schema'}->source($_)->name => $_ ) }
 		$self->{'_schema'}->sources;
 
@@ -106,8 +120,10 @@ sub insert {
 	return;
 }
 
-sub data {
-	err 'Package __PACKAGE__ is abstract class. data() method must be '.
+sub required_variables {
+	my $self = shift;
+
+	err 'Package __PACKAGE__ is abstract class. required_variables() method must be '.
 		'defined in inherited class.';
 }
 
